﻿Anritsu Company                                             MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub MG369XB Min/Max Power Sweep /ML2437
DATE:                  2009-09-10 13:46:16
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       163
CONFIGURATION:         Anritsu ML2437A
=============================================================================
#
#  Procedure Author:
#        DAC
#
#  Model(s) Covered:
#        MG369XB
#
#  Compatibility:
#        MET/CAL 7.20E or later
#
#  Subprocedures:
#        Sub Anritsu ML2430A Get Power Sensor Model
#        Sub Anritsu 41KC-S Get Attenuation
#        Sub Anritsu 41V-S Get Attenuation
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  The copyright for this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  IF           @LvldBm > +19
  1.002  MATH         Power = @LvldBm - 10
  1.003  ELSE
  1.004  MATH         Power = @LvldBm
  1.005  ENDIF

  1.006  MATH         N = 1; First = 1; PS = ""; Freq = @StartFreq
  1.007  MATH         FreqStep = (@StopFreq - @StartFreq) / @NumSteps

  1.008  DO

# Round the frequency to the number of digits the power meter is capable
# of resolving so the power level will fall into the ranges specified
# in the accuracy file.
  1.009  IF           Freq >= 1E+9
  1.010  MATH         @FreqGHz = CRND(Freq, 0.01E+9)/1E+9
  1.011  ELSE
  1.012  MATH         @FreqGHz = CRND(Freq, 0.01E+6)/1E+9
  1.013  ENDIF

  1.014  CALL         Sub MG369XB Connection /ML2437

  1.015  IEEE         RF0[D50]CF1[V @FreqGHz]GHL1[V @LvldBm]DM[D50]

# Anritsu recommends you zero the sensor on the UUT if taking a measurement
# near the sensitivity of the sensor.
  1.016  IF           Power <= @PS_MinLvl + 20
  1.017  ML2437       Zero; PowerSensor = [V @PS]
  1.018  ENDIF
  1.019  IEEE         RF1[D250]

# Throw away first reading if power sensor has changed.
  1.020  IF           NOT(ZCMP(@ML2430A_Sensor, PS))

# Use averaging for thermal sensors.
  1.021  IF           ZCMP(@PS_Series, "MA242X")

  1.022  IF           Power > -15
  1.023  MATH         AvgCnt = 32
  1.024  ELSE
  1.025  MATH         AvgCnt = 64
  1.026  ENDIF

  1.027  ENDIF

  1.028  IF           ZCMP(@PS_Series, "MA242X")
  1.029  ML2437       AveragingMode = Repeat; AverageCount = [V AvgCnt]
  1.029  ML2437       PowerSensor = [V @PS]; UUTSWR = [V @MG369XB_SWR]
  1.029  ML2437       +Power = [V Power] dBm; Freq = [V @FreqGHz] GHz
  1.030  ELSE
  1.031  ML2437       AveragingMode = Auto
  1.031  ML2437       PowerSensor = [V @PS]; UUTSWR = [V @MG369XB_SWR]
  1.031  ML2437       +Power = [V Power] dBm; Freq = [V @FreqGHz] GHz
  1.032  ENDIF

  1.033  MATH         PS = @ML2430A_Sensor
  1.034  ENDIF

  1.035  IF           ZCMP(@PS_Series, "MA242X")
  1.036  ML2437       AveragingMode = Repeat; AverageCount = [V AvgCnt]
  1.036  ML2437       PowerSensor = [V @PS]; UUTSWR = [V @MG369XB_SWR]
  1.036  ML2437       +Power = [V Power] dBm; Freq = [V @FreqGHz] GHz
  1.037  ELSE
  1.038  ML2437       AveragingMode = Auto
  1.038  ML2437       PowerSensor = [V @PS]; UUTSWR = [V @MG369XB_SWR]
  1.038  ML2437       +Power = [V Power] dBm; Freq = [V @FreqGHz] GHz
  1.039  ENDIF

# Get accuracy and convert to percent.
  1.040  MATH         PowerAccW = REFACC()

  1.041  IF           PowerAccW < 0
  1.042  DISP         REFACC() returned -1!
  1.042  DISP
  1.042  DISP         Cannot determine ML2430A measurement accuracy.
  1.043  END
  1.044  ENDIF

  1.045  MATH         PowerAcc  = PowerAccW / DBMTOW(MEM) * 100

  1.046  IF           FIND(@MG369XB_ML2430_Con, "10dB", 1)

  1.047  IF           ZCMP(@MG369XB_Con, "K")
  1.048  CALL         Sub Anritsu 41KC-S Get Attenuation
  1.049  ELSEIF       ZCMP(@MG369XB_Con, "V")
  1.050  CALL         Sub Anritsu 41V-S Get Attenuation
  1.051  ENDIF

  1.052  MATH         MEM = MEM + @AnritsuAttenVal
  1.053  ENDIF

  1.054  IF           First
  1.055  MATH         First = 0
  1.056  MATH         @MinPwrSensor = @ML2430A_Sensor
  1.057  MATH         @MaxPwrSensor = @ML2430A_Sensor
  1.058  MATH         @MinPwrFreq   = Freq
  1.059  MATH         @MaxPwrFreq   = Freq
  1.060  MATH         @MinPwr       = MEM
  1.061  MATH         @MaxPwr       = MEM
  1.062  MATH         @MinPwrAcc    = PowerAcc
  1.063  MATH         @MaxPwrAcc    = PowerAcc
  1.064  ELSEIF       MEM < @MinPwr
  1.065  MATH         @MinPwrSensor = @ML2430A_Sensor
  1.066  MATH         @MinPwrFreq   = Freq
  1.067  MATH         @MinPwr       = MEM
  1.068  MATH         @MinPwrAcc    = PowerAcc
  1.069  ELSEIF       MEM > @MaxPwr
  1.070  MATH         @MaxPwrSensor = @ML2430A_Sensor
  1.071  MATH         @MaxPwrFreq   = Freq
  1.072  MATH         @MaxPwr       = MEM
  1.073  MATH         @MaxPwrAcc    = PowerAcc
  1.074  ENDIF

  1.075  MATH         F    = ENGR_NSD(Freq, "Hz", 3)
  1.076  MATH         Pwr  = MEM & " dBm"
  1.077  MATH         Pmin = "Lo " & @MinPwr
  1.078  MATH         Pmax = "Hi " & @MaxPwr
  1.079  HEAD         -2 [V N]: [V F] [V Pwr] [V Pmin] [V Pmax]
  1.080  MATH         Freq = Freq + FreqStep; N = N + 1
  1.081  UNTIL        N > @NumSteps

  1.082  HEAD         -2
  1.083  END
